@@ -93,7 +93,9 @@ class Base:
             'secret': self._minio_secret,
             'client_kwargs':{
                 'endpoint_url': f"{_scheme}://{self._base_minio_url}"
-            }
+            },
+            'use_listings_cache': False,
+            'default_fill_cache': False,
         }
         if self._verbose: print("Init DataNode sucessful!")
         
