@@ -207,4 +207,10 @@ class DatasetManager(Base):
                           }
         )
         check.check_http_status_code(response=r)
-        return r.json()
\ No newline at end of file
+        return r.json()
+    
+    def get_meta_file(self, file_id):
+        _res = requests.get(f'{self._discovery_api}/file/{file_id}/',  headers=self._jwt_header)
+        if _res.status_code > 200:
+            raise Exception(f'Cannot read meta data of file_id {file_id}')
+        return _res.json()
\ No newline at end of file
